api

package
v0.0.0-...-24ec843 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 1, 2024 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_meridian_model_proto protoreflect.FileDescriptor
var File_meridian_proto protoreflect.FileDescriptor
var Meridian_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "proto.Meridian",
	HandlerType: (*MeridianServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AddNamespace",
			Handler:    _Meridian_AddNamespace_Handler,
		},
		{
			MethodName: "RemoveNamespace",
			Handler:    _Meridian_RemoveNamespace_Handler,
		},
		{
			MethodName: "AddApp",
			Handler:    _Meridian_AddApp_Handler,
		},
		{
			MethodName: "RemoveApp",
			Handler:    _Meridian_RemoveApp_Handler,
		},
		{
			MethodName: "GetNamespace",
			Handler:    _Meridian_GetNamespace_Handler,
		},
		{
			MethodName: "GetNamespaceHierarchy",
			Handler:    _Meridian_GetNamespaceHierarchy_Handler,
		},
		{
			MethodName: "SetNamespaceResources",
			Handler:    _Meridian_SetNamespaceResources_Handler,
		},
		{
			MethodName: "SetAppResources",
			Handler:    _Meridian_SetAppResources_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "meridian.proto",
}

Meridian_ServiceDesc is the grpc.ServiceDesc for Meridian service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterMeridianServer

func RegisterMeridianServer(s grpc.ServiceRegistrar, srv MeridianServer)

func Subject

func Subject(nodeId string) string

Types

type AddAppReq

type AddAppReq struct {
	OrgId                     string             `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Namespace                 string             `protobuf:"bytes,2,opt,name=namespace,proto3" json:"namespace,omitempty"`
	Name                      string             `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	Quotas                    map[string]float64 `` /* 155-byte string literal not displayed */
	Profile                   *SeccompProfile    `protobuf:"bytes,5,opt,name=profile,proto3" json:"profile,omitempty"`
	SeccompDefinitionStrategy string             `protobuf:"bytes,6,opt,name=seccompDefinitionStrategy,proto3" json:"seccompDefinitionStrategy,omitempty"`
	// contains filtered or unexported fields
}

func (*AddAppReq) Descriptor deprecated

func (*AddAppReq) Descriptor() ([]byte, []int)

Deprecated: Use AddAppReq.ProtoReflect.Descriptor instead.

func (*AddAppReq) GetName

func (x *AddAppReq) GetName() string

func (*AddAppReq) GetNamespace

func (x *AddAppReq) GetNamespace() string

func (*AddAppReq) GetOrgId

func (x *AddAppReq) GetOrgId() string

func (*AddAppReq) GetProfile

func (x *AddAppReq) GetProfile() *SeccompProfile

func (*AddAppReq) GetQuotas

func (x *AddAppReq) GetQuotas() map[string]float64

func (*AddAppReq) GetSeccompDefinitionStrategy

func (x *AddAppReq) GetSeccompDefinitionStrategy() string

func (*AddAppReq) ProtoMessage

func (*AddAppReq) ProtoMessage()

func (*AddAppReq) ProtoReflect

func (x *AddAppReq) ProtoReflect() protoreflect.Message

func (*AddAppReq) Reset

func (x *AddAppReq) Reset()

func (*AddAppReq) String

func (x *AddAppReq) String() string

type AddAppResp

type AddAppResp struct {
	// contains filtered or unexported fields
}

func (*AddAppResp) Descriptor deprecated

func (*AddAppResp) Descriptor() ([]byte, []int)

Deprecated: Use AddAppResp.ProtoReflect.Descriptor instead.

func (*AddAppResp) ProtoMessage

func (*AddAppResp) ProtoMessage()

func (*AddAppResp) ProtoReflect

func (x *AddAppResp) ProtoReflect() protoreflect.Message

func (*AddAppResp) Reset

func (x *AddAppResp) Reset()

func (*AddAppResp) String

func (x *AddAppResp) String() string

type AddNamespaceReq

type AddNamespaceReq struct {
	OrgId                     string             `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Name                      string             `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Labels                    map[string]string  `` /* 153-byte string literal not displayed */
	Quotas                    map[string]float64 `` /* 155-byte string literal not displayed */
	SeccompDefinitionStrategy string             `protobuf:"bytes,5,opt,name=seccompDefinitionStrategy,proto3" json:"seccompDefinitionStrategy,omitempty"`
	Profile                   *SeccompProfile    `protobuf:"bytes,6,opt,name=profile,proto3" json:"profile,omitempty"`
	ParentName                string             `protobuf:"bytes,7,opt,name=parentName,proto3" json:"parentName,omitempty"`
	// contains filtered or unexported fields
}

func (*AddNamespaceReq) Descriptor deprecated

func (*AddNamespaceReq) Descriptor() ([]byte, []int)

Deprecated: Use AddNamespaceReq.ProtoReflect.Descriptor instead.

func (*AddNamespaceReq) GetLabels

func (x *AddNamespaceReq) GetLabels() map[string]string

func (*AddNamespaceReq) GetName

func (x *AddNamespaceReq) GetName() string

func (*AddNamespaceReq) GetOrgId

func (x *AddNamespaceReq) GetOrgId() string

func (*AddNamespaceReq) GetParentName

func (x *AddNamespaceReq) GetParentName() string

func (*AddNamespaceReq) GetProfile

func (x *AddNamespaceReq) GetProfile() *SeccompProfile

func (*AddNamespaceReq) GetQuotas

func (x *AddNamespaceReq) GetQuotas() map[string]float64

func (*AddNamespaceReq) GetSeccompDefinitionStrategy

func (x *AddNamespaceReq) GetSeccompDefinitionStrategy() string

func (*AddNamespaceReq) ProtoMessage

func (*AddNamespaceReq) ProtoMessage()

func (*AddNamespaceReq) ProtoReflect

func (x *AddNamespaceReq) ProtoReflect() protoreflect.Message

func (*AddNamespaceReq) Reset

func (x *AddNamespaceReq) Reset()

func (*AddNamespaceReq) String

func (x *AddNamespaceReq) String() string

type AddNamespaceResp

type AddNamespaceResp struct {
	// contains filtered or unexported fields
}

func (*AddNamespaceResp) Descriptor deprecated

func (*AddNamespaceResp) Descriptor() ([]byte, []int)

Deprecated: Use AddNamespaceResp.ProtoReflect.Descriptor instead.

func (*AddNamespaceResp) ProtoMessage

func (*AddNamespaceResp) ProtoMessage()

func (*AddNamespaceResp) ProtoReflect

func (x *AddNamespaceResp) ProtoReflect() protoreflect.Message

func (*AddNamespaceResp) Reset

func (x *AddNamespaceResp) Reset()

func (*AddNamespaceResp) String

func (x *AddNamespaceResp) String() string

type ApplyAppConfigCommand

type ApplyAppConfigCommand struct {
	OrgId          string             `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	NamespaceName  string             `protobuf:"bytes,2,opt,name=namespaceName,proto3" json:"namespaceName,omitempty"`
	AppName        string             `protobuf:"bytes,3,opt,name=appName,proto3" json:"appName,omitempty"`
	SeccompProfile string             `protobuf:"bytes,4,opt,name=seccompProfile,proto3" json:"seccompProfile,omitempty"`
	Quotas         map[string]float64 `` /* 155-byte string literal not displayed */
	Strategy       string             `protobuf:"bytes,6,opt,name=strategy,proto3" json:"strategy,omitempty"`
	// contains filtered or unexported fields
}

func (*ApplyAppConfigCommand) Descriptor deprecated

func (*ApplyAppConfigCommand) Descriptor() ([]byte, []int)

Deprecated: Use ApplyAppConfigCommand.ProtoReflect.Descriptor instead.

func (*ApplyAppConfigCommand) GetAppName

func (x *ApplyAppConfigCommand) GetAppName() string

func (*ApplyAppConfigCommand) GetNamespaceName

func (x *ApplyAppConfigCommand) GetNamespaceName() string

func (*ApplyAppConfigCommand) GetOrgId

func (x *ApplyAppConfigCommand) GetOrgId() string

func (*ApplyAppConfigCommand) GetQuotas

func (x *ApplyAppConfigCommand) GetQuotas() map[string]float64

func (*ApplyAppConfigCommand) GetSeccompProfile

func (x *ApplyAppConfigCommand) GetSeccompProfile() string

func (*ApplyAppConfigCommand) GetStrategy

func (x *ApplyAppConfigCommand) GetStrategy() string

func (*ApplyAppConfigCommand) ProtoMessage

func (*ApplyAppConfigCommand) ProtoMessage()

func (*ApplyAppConfigCommand) ProtoReflect

func (x *ApplyAppConfigCommand) ProtoReflect() protoreflect.Message

func (*ApplyAppConfigCommand) Reset

func (x *ApplyAppConfigCommand) Reset()

func (*ApplyAppConfigCommand) String

func (x *ApplyAppConfigCommand) String() string

type ApplyAppConfigHandler

type ApplyAppConfigHandler func(orgId, namespaceName, appName, seccompProfile, strategy string, quotas map[string]float64) error

type GetNamespaceHierarchyReq

type GetNamespaceHierarchyReq struct {
	OrgId string `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNamespaceHierarchyReq) Descriptor deprecated

func (*GetNamespaceHierarchyReq) Descriptor() ([]byte, []int)

Deprecated: Use GetNamespaceHierarchyReq.ProtoReflect.Descriptor instead.

func (*GetNamespaceHierarchyReq) GetOrgId

func (x *GetNamespaceHierarchyReq) GetOrgId() string

func (*GetNamespaceHierarchyReq) ProtoMessage

func (*GetNamespaceHierarchyReq) ProtoMessage()

func (*GetNamespaceHierarchyReq) ProtoReflect

func (x *GetNamespaceHierarchyReq) ProtoReflect() protoreflect.Message

func (*GetNamespaceHierarchyReq) Reset

func (x *GetNamespaceHierarchyReq) Reset()

func (*GetNamespaceHierarchyReq) String

func (x *GetNamespaceHierarchyReq) String() string

type GetNamespaceHierarchyResp

type GetNamespaceHierarchyResp struct {
	Namespace  *GetNamespaceHierarchyResp_Namespace `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
	Apps       []*GetNamespaceHierarchyResp_App     `protobuf:"bytes,2,rep,name=apps,proto3" json:"apps,omitempty"`
	Namespaces []*GetNamespaceHierarchyResp         `protobuf:"bytes,3,rep,name=namespaces,proto3" json:"namespaces,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNamespaceHierarchyResp) Descriptor deprecated

func (*GetNamespaceHierarchyResp) Descriptor() ([]byte, []int)

Deprecated: Use GetNamespaceHierarchyResp.ProtoReflect.Descriptor instead.

func (*GetNamespaceHierarchyResp) GetApps

func (*GetNamespaceHierarchyResp) GetNamespace

func (*GetNamespaceHierarchyResp) GetNamespaces

func (*GetNamespaceHierarchyResp) ProtoMessage

func (*GetNamespaceHierarchyResp) ProtoMessage()

func (*GetNamespaceHierarchyResp) ProtoReflect

func (*GetNamespaceHierarchyResp) Reset

func (x *GetNamespaceHierarchyResp) Reset()

func (*GetNamespaceHierarchyResp) String

func (x *GetNamespaceHierarchyResp) String() string

type GetNamespaceHierarchyResp_App

type GetNamespaceHierarchyResp_App struct {
	Name    string             `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Total   map[string]float64 `` /* 153-byte string literal not displayed */
	Profile *SeccompProfile    `protobuf:"bytes,6,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNamespaceHierarchyResp_App) Descriptor deprecated

func (*GetNamespaceHierarchyResp_App) Descriptor() ([]byte, []int)

Deprecated: Use GetNamespaceHierarchyResp_App.ProtoReflect.Descriptor instead.

func (*GetNamespaceHierarchyResp_App) GetName

func (*GetNamespaceHierarchyResp_App) GetProfile

func (*GetNamespaceHierarchyResp_App) GetTotal

func (x *GetNamespaceHierarchyResp_App) GetTotal() map[string]float64

func (*GetNamespaceHierarchyResp_App) ProtoMessage

func (*GetNamespaceHierarchyResp_App) ProtoMessage()

func (*GetNamespaceHierarchyResp_App) ProtoReflect

func (*GetNamespaceHierarchyResp_App) Reset

func (x *GetNamespaceHierarchyResp_App) Reset()

func (*GetNamespaceHierarchyResp_App) String

type GetNamespaceHierarchyResp_Namespace

type GetNamespaceHierarchyResp_Namespace struct {
	Name      string             `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Labels    map[string]string  `` /* 153-byte string literal not displayed */
	Total     map[string]float64 `` /* 153-byte string literal not displayed */
	Available map[string]float64 `` /* 161-byte string literal not displayed */
	Utilized  map[string]float64 `` /* 159-byte string literal not displayed */
	Profile   *SeccompProfile    `protobuf:"bytes,6,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNamespaceHierarchyResp_Namespace) Descriptor deprecated

func (*GetNamespaceHierarchyResp_Namespace) Descriptor() ([]byte, []int)

Deprecated: Use GetNamespaceHierarchyResp_Namespace.ProtoReflect.Descriptor instead.

func (*GetNamespaceHierarchyResp_Namespace) GetAvailable

func (x *GetNamespaceHierarchyResp_Namespace) GetAvailable() map[string]float64

func (*GetNamespaceHierarchyResp_Namespace) GetLabels

func (*GetNamespaceHierarchyResp_Namespace) GetName

func (*GetNamespaceHierarchyResp_Namespace) GetProfile

func (*GetNamespaceHierarchyResp_Namespace) GetTotal

func (*GetNamespaceHierarchyResp_Namespace) GetUtilized

func (x *GetNamespaceHierarchyResp_Namespace) GetUtilized() map[string]float64

func (*GetNamespaceHierarchyResp_Namespace) ProtoMessage

func (*GetNamespaceHierarchyResp_Namespace) ProtoMessage()

func (*GetNamespaceHierarchyResp_Namespace) ProtoReflect

func (*GetNamespaceHierarchyResp_Namespace) Reset

func (*GetNamespaceHierarchyResp_Namespace) String

type GetNamespaceReq

type GetNamespaceReq struct {
	OrgId string `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Name  string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNamespaceReq) Descriptor deprecated

func (*GetNamespaceReq) Descriptor() ([]byte, []int)

Deprecated: Use GetNamespaceReq.ProtoReflect.Descriptor instead.

func (*GetNamespaceReq) GetName

func (x *GetNamespaceReq) GetName() string

func (*GetNamespaceReq) GetOrgId

func (x *GetNamespaceReq) GetOrgId() string

func (*GetNamespaceReq) ProtoMessage

func (*GetNamespaceReq) ProtoMessage()

func (*GetNamespaceReq) ProtoReflect

func (x *GetNamespaceReq) ProtoReflect() protoreflect.Message

func (*GetNamespaceReq) Reset

func (x *GetNamespaceReq) Reset()

func (*GetNamespaceReq) String

func (x *GetNamespaceReq) String() string

type GetNamespaceResp

type GetNamespaceResp struct {
	Name      string             `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Labels    map[string]string  `` /* 153-byte string literal not displayed */
	Total     map[string]float64 `` /* 153-byte string literal not displayed */
	Available map[string]float64 `` /* 161-byte string literal not displayed */
	Utilized  map[string]float64 `` /* 159-byte string literal not displayed */
	Profile   *SeccompProfile    `protobuf:"bytes,6,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*GetNamespaceResp) Descriptor deprecated

func (*GetNamespaceResp) Descriptor() ([]byte, []int)

Deprecated: Use GetNamespaceResp.ProtoReflect.Descriptor instead.

func (*GetNamespaceResp) GetAvailable

func (x *GetNamespaceResp) GetAvailable() map[string]float64

func (*GetNamespaceResp) GetLabels

func (x *GetNamespaceResp) GetLabels() map[string]string

func (*GetNamespaceResp) GetName

func (x *GetNamespaceResp) GetName() string

func (*GetNamespaceResp) GetProfile

func (x *GetNamespaceResp) GetProfile() *SeccompProfile

func (*GetNamespaceResp) GetTotal

func (x *GetNamespaceResp) GetTotal() map[string]float64

func (*GetNamespaceResp) GetUtilized

func (x *GetNamespaceResp) GetUtilized() map[string]float64

func (*GetNamespaceResp) ProtoMessage

func (*GetNamespaceResp) ProtoMessage()

func (*GetNamespaceResp) ProtoReflect

func (x *GetNamespaceResp) ProtoReflect() protoreflect.Message

func (*GetNamespaceResp) Reset

func (x *GetNamespaceResp) Reset()

func (*GetNamespaceResp) String

func (x *GetNamespaceResp) String() string

type MeridianAsyncClient

type MeridianAsyncClient struct {
	// contains filtered or unexported fields
}

func NewMeridianAsyncClient

func NewMeridianAsyncClient(address, nodeId string) (*MeridianAsyncClient, error)

func (*MeridianAsyncClient) GracefulStop

func (c *MeridianAsyncClient) GracefulStop()

func (*MeridianAsyncClient) ReceiveConfig

func (c *MeridianAsyncClient) ReceiveConfig(handler ApplyAppConfigHandler) error

type MeridianClient

type MeridianClient interface {
	AddNamespace(ctx context.Context, in *AddNamespaceReq, opts ...grpc.CallOption) (*AddNamespaceResp, error)
	RemoveNamespace(ctx context.Context, in *RemoveNamespaceReq, opts ...grpc.CallOption) (*RemoveNamespaceResp, error)
	AddApp(ctx context.Context, in *AddAppReq, opts ...grpc.CallOption) (*AddAppResp, error)
	RemoveApp(ctx context.Context, in *RemoveAppReq, opts ...grpc.CallOption) (*RemoveAppResp, error)
	GetNamespace(ctx context.Context, in *GetNamespaceReq, opts ...grpc.CallOption) (*GetNamespaceResp, error)
	GetNamespaceHierarchy(ctx context.Context, in *GetNamespaceHierarchyReq, opts ...grpc.CallOption) (*GetNamespaceHierarchyResp, error)
	SetNamespaceResources(ctx context.Context, in *SetNamespaceResourcesReq, opts ...grpc.CallOption) (*SetNamespaceResourcesResp, error)
	SetAppResources(ctx context.Context, in *SetAppResourcesReq, opts ...grpc.CallOption) (*SetAppResourcesResp, error)
}

MeridianClient is the client API for Meridian service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewMeridianClient

func NewMeridianClient(cc grpc.ClientConnInterface) MeridianClient

type MeridianServer

type MeridianServer interface {
	AddNamespace(context.Context, *AddNamespaceReq) (*AddNamespaceResp, error)
	RemoveNamespace(context.Context, *RemoveNamespaceReq) (*RemoveNamespaceResp, error)
	AddApp(context.Context, *AddAppReq) (*AddAppResp, error)
	RemoveApp(context.Context, *RemoveAppReq) (*RemoveAppResp, error)
	GetNamespace(context.Context, *GetNamespaceReq) (*GetNamespaceResp, error)
	GetNamespaceHierarchy(context.Context, *GetNamespaceHierarchyReq) (*GetNamespaceHierarchyResp, error)
	SetNamespaceResources(context.Context, *SetNamespaceResourcesReq) (*SetNamespaceResourcesResp, error)
	SetAppResources(context.Context, *SetAppResourcesReq) (*SetAppResourcesResp, error)
	// contains filtered or unexported methods
}

MeridianServer is the server API for Meridian service. All implementations must embed UnimplementedMeridianServer for forward compatibility

type RemoveAppReq

type RemoveAppReq struct {
	OrgId     string `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Namespace string `protobuf:"bytes,2,opt,name=namespace,proto3" json:"namespace,omitempty"`
	Name      string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*RemoveAppReq) Descriptor deprecated

func (*RemoveAppReq) Descriptor() ([]byte, []int)

Deprecated: Use RemoveAppReq.ProtoReflect.Descriptor instead.

func (*RemoveAppReq) GetName

func (x *RemoveAppReq) GetName() string

func (*RemoveAppReq) GetNamespace

func (x *RemoveAppReq) GetNamespace() string

func (*RemoveAppReq) GetOrgId

func (x *RemoveAppReq) GetOrgId() string

func (*RemoveAppReq) ProtoMessage

func (*RemoveAppReq) ProtoMessage()

func (*RemoveAppReq) ProtoReflect

func (x *RemoveAppReq) ProtoReflect() protoreflect.Message

func (*RemoveAppReq) Reset

func (x *RemoveAppReq) Reset()

func (*RemoveAppReq) String

func (x *RemoveAppReq) String() string

type RemoveAppResp

type RemoveAppResp struct {
	// contains filtered or unexported fields
}

func (*RemoveAppResp) Descriptor deprecated

func (*RemoveAppResp) Descriptor() ([]byte, []int)

Deprecated: Use RemoveAppResp.ProtoReflect.Descriptor instead.

func (*RemoveAppResp) ProtoMessage

func (*RemoveAppResp) ProtoMessage()

func (*RemoveAppResp) ProtoReflect

func (x *RemoveAppResp) ProtoReflect() protoreflect.Message

func (*RemoveAppResp) Reset

func (x *RemoveAppResp) Reset()

func (*RemoveAppResp) String

func (x *RemoveAppResp) String() string

type RemoveNamespaceReq

type RemoveNamespaceReq struct {
	OrgId string `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Name  string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*RemoveNamespaceReq) Descriptor deprecated

func (*RemoveNamespaceReq) Descriptor() ([]byte, []int)

Deprecated: Use RemoveNamespaceReq.ProtoReflect.Descriptor instead.

func (*RemoveNamespaceReq) GetName

func (x *RemoveNamespaceReq) GetName() string

func (*RemoveNamespaceReq) GetOrgId

func (x *RemoveNamespaceReq) GetOrgId() string

func (*RemoveNamespaceReq) ProtoMessage

func (*RemoveNamespaceReq) ProtoMessage()

func (*RemoveNamespaceReq) ProtoReflect

func (x *RemoveNamespaceReq) ProtoReflect() protoreflect.Message

func (*RemoveNamespaceReq) Reset

func (x *RemoveNamespaceReq) Reset()

func (*RemoveNamespaceReq) String

func (x *RemoveNamespaceReq) String() string

type RemoveNamespaceResp

type RemoveNamespaceResp struct {
	// contains filtered or unexported fields
}

func (*RemoveNamespaceResp) Descriptor deprecated

func (*RemoveNamespaceResp) Descriptor() ([]byte, []int)

Deprecated: Use RemoveNamespaceResp.ProtoReflect.Descriptor instead.

func (*RemoveNamespaceResp) ProtoMessage

func (*RemoveNamespaceResp) ProtoMessage()

func (*RemoveNamespaceResp) ProtoReflect

func (x *RemoveNamespaceResp) ProtoReflect() protoreflect.Message

func (*RemoveNamespaceResp) Reset

func (x *RemoveNamespaceResp) Reset()

func (*RemoveNamespaceResp) String

func (x *RemoveNamespaceResp) String() string

type SeccompProfile

type SeccompProfile struct {
	Version       string         `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	DefaultAction string         `protobuf:"bytes,3,opt,name=defaultAction,proto3" json:"defaultAction,omitempty"`
	Syscalls      []*SyscallRule `protobuf:"bytes,4,rep,name=syscalls,proto3" json:"syscalls,omitempty"`
	// contains filtered or unexported fields
}

func (*SeccompProfile) Descriptor deprecated

func (*SeccompProfile) Descriptor() ([]byte, []int)

Deprecated: Use SeccompProfile.ProtoReflect.Descriptor instead.

func (*SeccompProfile) GetDefaultAction

func (x *SeccompProfile) GetDefaultAction() string

func (*SeccompProfile) GetSyscalls

func (x *SeccompProfile) GetSyscalls() []*SyscallRule

func (*SeccompProfile) GetVersion

func (x *SeccompProfile) GetVersion() string

func (*SeccompProfile) ProtoMessage

func (*SeccompProfile) ProtoMessage()

func (*SeccompProfile) ProtoReflect

func (x *SeccompProfile) ProtoReflect() protoreflect.Message

func (*SeccompProfile) Reset

func (x *SeccompProfile) Reset()

func (*SeccompProfile) String

func (x *SeccompProfile) String() string

type SetAppResourcesReq

type SetAppResourcesReq struct {
	OrgId     string             `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Namespace string             `protobuf:"bytes,2,opt,name=namespace,proto3" json:"namespace,omitempty"`
	Name      string             `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	Quotas    map[string]float64 `` /* 155-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*SetAppResourcesReq) Descriptor deprecated

func (*SetAppResourcesReq) Descriptor() ([]byte, []int)

Deprecated: Use SetAppResourcesReq.ProtoReflect.Descriptor instead.

func (*SetAppResourcesReq) GetName

func (x *SetAppResourcesReq) GetName() string

func (*SetAppResourcesReq) GetNamespace

func (x *SetAppResourcesReq) GetNamespace() string

func (*SetAppResourcesReq) GetOrgId

func (x *SetAppResourcesReq) GetOrgId() string

func (*SetAppResourcesReq) GetQuotas

func (x *SetAppResourcesReq) GetQuotas() map[string]float64

func (*SetAppResourcesReq) ProtoMessage

func (*SetAppResourcesReq) ProtoMessage()

func (*SetAppResourcesReq) ProtoReflect

func (x *SetAppResourcesReq) ProtoReflect() protoreflect.Message

func (*SetAppResourcesReq) Reset

func (x *SetAppResourcesReq) Reset()

func (*SetAppResourcesReq) String

func (x *SetAppResourcesReq) String() string

type SetAppResourcesResp

type SetAppResourcesResp struct {
	// contains filtered or unexported fields
}

func (*SetAppResourcesResp) Descriptor deprecated

func (*SetAppResourcesResp) Descriptor() ([]byte, []int)

Deprecated: Use SetAppResourcesResp.ProtoReflect.Descriptor instead.

func (*SetAppResourcesResp) ProtoMessage

func (*SetAppResourcesResp) ProtoMessage()

func (*SetAppResourcesResp) ProtoReflect

func (x *SetAppResourcesResp) ProtoReflect() protoreflect.Message

func (*SetAppResourcesResp) Reset

func (x *SetAppResourcesResp) Reset()

func (*SetAppResourcesResp) String

func (x *SetAppResourcesResp) String() string

type SetNamespaceResourcesReq

type SetNamespaceResourcesReq struct {
	OrgId  string             `protobuf:"bytes,1,opt,name=orgId,proto3" json:"orgId,omitempty"`
	Name   string             `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Quotas map[string]float64 `` /* 155-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*SetNamespaceResourcesReq) Descriptor deprecated

func (*SetNamespaceResourcesReq) Descriptor() ([]byte, []int)

Deprecated: Use SetNamespaceResourcesReq.ProtoReflect.Descriptor instead.

func (*SetNamespaceResourcesReq) GetName

func (x *SetNamespaceResourcesReq) GetName() string

func (*SetNamespaceResourcesReq) GetOrgId

func (x *SetNamespaceResourcesReq) GetOrgId() string

func (*SetNamespaceResourcesReq) GetQuotas

func (x *SetNamespaceResourcesReq) GetQuotas() map[string]float64

func (*SetNamespaceResourcesReq) ProtoMessage

func (*SetNamespaceResourcesReq) ProtoMessage()

func (*SetNamespaceResourcesReq) ProtoReflect

func (x *SetNamespaceResourcesReq) ProtoReflect() protoreflect.Message

func (*SetNamespaceResourcesReq) Reset

func (x *SetNamespaceResourcesReq) Reset()

func (*SetNamespaceResourcesReq) String

func (x *SetNamespaceResourcesReq) String() string

type SetNamespaceResourcesResp

type SetNamespaceResourcesResp struct {
	// contains filtered or unexported fields
}

func (*SetNamespaceResourcesResp) Descriptor deprecated

func (*SetNamespaceResourcesResp) Descriptor() ([]byte, []int)

Deprecated: Use SetNamespaceResourcesResp.ProtoReflect.Descriptor instead.

func (*SetNamespaceResourcesResp) ProtoMessage

func (*SetNamespaceResourcesResp) ProtoMessage()

func (*SetNamespaceResourcesResp) ProtoReflect

func (*SetNamespaceResourcesResp) Reset

func (x *SetNamespaceResourcesResp) Reset()

func (*SetNamespaceResourcesResp) String

func (x *SetNamespaceResourcesResp) String() string

type SyscallRule

type SyscallRule struct {
	Names  []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
	Action string   `protobuf:"bytes,2,opt,name=action,proto3" json:"action,omitempty"`
	// contains filtered or unexported fields
}

func (*SyscallRule) Descriptor deprecated

func (*SyscallRule) Descriptor() ([]byte, []int)

Deprecated: Use SyscallRule.ProtoReflect.Descriptor instead.

func (*SyscallRule) GetAction

func (x *SyscallRule) GetAction() string

func (*SyscallRule) GetNames

func (x *SyscallRule) GetNames() []string

func (*SyscallRule) ProtoMessage

func (*SyscallRule) ProtoMessage()

func (*SyscallRule) ProtoReflect

func (x *SyscallRule) ProtoReflect() protoreflect.Message

func (*SyscallRule) Reset

func (x *SyscallRule) Reset()

func (*SyscallRule) String

func (x *SyscallRule) String() string

type UnimplementedMeridianServer

type UnimplementedMeridianServer struct {
}

UnimplementedMeridianServer must be embedded to have forward compatible implementations.

func (UnimplementedMeridianServer) AddApp

func (UnimplementedMeridianServer) AddNamespace

func (UnimplementedMeridianServer) GetNamespace

func (UnimplementedMeridianServer) GetNamespaceHierarchy

func (UnimplementedMeridianServer) RemoveApp

func (UnimplementedMeridianServer) RemoveNamespace

func (UnimplementedMeridianServer) SetAppResources

func (UnimplementedMeridianServer) SetNamespaceResources

type UnsafeMeridianServer

type UnsafeMeridianServer interface {
	// contains filtered or unexported methods
}

UnsafeMeridianServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MeridianServer will result in compilation errors.

Jump to